@@ -151,7 +151,7 @@ def to_xarray(
     for s in molecules:
         xs = df[s].values * 1e-6  # raw data mixing ratios are in ppmv
         x_values.append(xs)
-    x = ureg.Quantity(np.array(x_values), "")
+    x = ureg.Quantity(np.array(x_values), "")  # type: ignore[var-annotated]
 
     ds: xr.Dataset = make_data_set(  # type: ignore
         p=p,
@@ -159,7 +159,7 @@ def to_xarray(
         n=n,
         x=x,
         z=z,
-        m=np.array(molecules),
+        m=molecules,
         title=f"AFGL (1986) {identifier.value.replace('_', '-')} atmospheric profile",
         source=SOURCE,
         references=REFERENCE,
