@@ -135,7 +135,10 @@ def _parse_content(lines: t.List[str]) -> t.Dict[str, pint.Quantity]:  # type: i
         elif line.startswith("*"):
             # convert previously read values (if any) and units to quantity
             if len(values) > 0:
-                quantity = ureg.Quantity(np.array(values, dtype=float), units)
+                quantity = ureg.Quantity(
+                    np.array(values, dtype=float),
+                    units,
+                )  # type: ignore[var-annotated]
                 _add_to_quantities(quantity=quantity, name=var)
 
             # this is a variable line, parse variable name and units
@@ -288,20 +291,25 @@ def read(
     p = quantities.pop("p")
     t = quantities.pop("t")
     n = p / (K * t)  # perfect gas equation
-    molecules = np.array(list(quantities.keys()))
-    x = np.array([quantities[molecule].magnitude for molecule in molecules])
+    molecules = list(quantities.keys())
+    x = (
+        np.array([quantities[molecule].magnitude for molecule in molecules])
+        * ureg.dimensionless
+    )  # type: ignore[var-annotated]
 
     if additional_molecules:
         extra_quantities, extra_url_info = read_additional_molecules(
             identifier=identifier
         )
         extra_z = extra_quantities.pop("z")
-        extra_molecules = np.array(list(extra_quantities.keys()))
-        extra_x = np.array([extra_quantities[s].magnitude for s in extra_molecules])
+        extra_m = list(extra_quantities.keys())
+        extra_x = np.array(
+            [extra_quantities[s].magnitude for s in extra_m]
+        )  # type: ignore[var-annotated]
 
         # initial molecules
         da = xr.DataArray(
-            x,
+            x.m,
             dims=["molecules", "z"],
             coords={"molecules": molecules, "z": z.magnitude},
         )
@@ -311,19 +319,21 @@ def read(
             extra_x,
             dims=["molecules", "z"],
             coords={
-                "molecules": extra_molecules,
+                "molecules": extra_m,
                 "z": extra_z.m_as(z.units),
             },
         )
 
         # interpolate additional molecules mixing ratio on altitude mesh used
         # for initial molecules mixing ratio:
-        da_extra_interp = np.exp(np.log(da_extra).interp(z=z.m_as(z.units)))
+        da_extra_interp = np.exp(
+            np.log(da_extra).interp(z=z.m_as(z.units))  # type: ignore
+        )
 
         # concatenate initial and additional molecules
         da_total = xr.concat([da, da_extra_interp], dim="molecules")
-        molecules = da_total.molecules.values
-        x = da_total.values
+        molecules = list(da_total.molecules.values)
+        x = da_total.values * ureg.dimensionless
 
     ds = make_data_set(
         p=p,
